OC.L10N.register(
    "spreed",
    {
    "a conversation" : "un diviz",
    "(Duration %s)" : "(Padelezh %s)",
    "You attended a call with {user1}" : "Ur galvavadenn o peus bet gant {user1}",
    "_%n guest_::_%n guests_" : ["%n gouviad","%n gouviad","%n gouviad","%n gouviad","%n gouviad"],
    "You attended a call with {user1} and {user2}" : "Ur galvavadenn o peus bet gant {user1} ha {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Ur galvavadenn o peus bet gant {user1}, {user2} ha {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Ur galvavadenn o peus bet gant {user1}, {user2}, {user3} ha {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Ur galvavadenn o peus bet gant {user1}, {user2}, {user3}, {user4} ha {user5}",
    "_%n other_::_%n others_" : ["%n all","%n all","%n all","%n all","%n all"],
    "{actor} invited you to {call}" : "Kouviet oc'h da {call} gant {actor}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Kouviet oc'h d'un <strong>diviz</strong> pe ouzhpennet d'ur <strong>galvadenn</strong>",
    "Other activities" : "Oberiantizoù all",
    "Talk" : "Komz",
    "Guest" : "Kouviad",
    "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Donemat war Nextcloud Talk !\nEn diviz-mañ e voc'h kemenet diwar-benn perzhioù nevez a kavoc'h e Nextcloud Talk.",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Micosoft Edge ha Safari a zo posupl implij evit ar gemenadenoù audio a video",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Posupl eo deoc'h gervel tout en dud en diviz en ur skrivañ \"@all\" er chat",
    "- With the \"arrow-up\" key you can repost your last message" : " -Gant an douchenn \"bir-a-uz\" en posupl adkas ar gemenadenn divezhañ",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk en deus urzioù bremañ, kasit \"/help\" evel ur gemenadenn chat evit gwelet m'az eo bet stummet urzioù gant o merour",
    "- With projects you can create quick links between conversations, files and other items" : "- Gant Raktres eo posupl deoc'h krouiñ liammoù etre an divizoù, restroù ha traoù all",
    "- You can now mention guests in the chat" : "- Posuple eo deoc'h menegiñ kouvidi er chat",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Ur sal gortoz eo posupl kaout evit an divizoù. Aotreañ a raio an habaskaerien da vont er chat hag er gemenaden evit prientiñ ar gejadenn, padal eo ret d'an implijourien ha d'ar gouviidi gortoz",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Posupl eo deoc'h respont diouzhtu d'ar gemenadennoù en ur displegañ diwar benn petra eo ar gemenadenn.",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Klask divizoù ha lodeget a implijo ivez ho divizoù, ma vo aesoc'h adkavout divizoù kozh",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Posupl eo deoc'h ouzhpenañ strolladoù implijourien personelaet d'an divizoù gant ar meziant kelc'h staliet",
    "- Check out the new grid and call view" : "- Sellit ouzh ar rouedad ha kemener nevez",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Posuple eo deoc'h pelkas ha ruzañ-lakaat restroù diozhtu eus o ardivink er chat",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Restrom rannet a vez igoret diozhtu er chat gant ar lenner maziant",
    "There are currently no commands available." : "N'ez us linenn urzh ebet evit ar poent",
    "The command does not exist" : "N'ez eus ket eyus an urzh",
    "An error occurred while running the command. Please ask an administrator to check the logs." : "Ur fazi a zo bet en ur ober an urzh. Goulennit d'ar merour da sellet ouzh ar gazetenn.",
    "Talk updates ✅" : "Adnevesaden Talk ✅",
    "{actor} created the conversation" : "{actor} en deus krouet an diviz",
    "You created the conversation" : "Krouet o peus an diviz",
    "An administrator created the conversation" : "Ar merour en deus krouet an diviz",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} en deus adenvet an diviz eus \"%1$s\" da \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Adenvet o peus an diviz eus \"%1$s\" da \"%2$s\"",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Ar merour en deus adenvet an diviz eus \"%1$s\" da \"%2$s\"",
    "{actor} started a call" : "{actor} en deus kroget ur gemenadenn",
    "You started a call" : "Kroget o peus ur gemenadenn",
    "{actor} joined the call" : "{actor} a zo deuet er gemenadenn",
    "You joined the call" : "Deuet oc'h er gemenaden",
    "{actor} left the call" : "{actor} en deus kuitaet ar gemenadenn",
    "You left the call" : "Kuitaet o peus ar gemenaden",
    "{actor} unlocked the conversation" : "{actor} en deus digoret ar gemenadenn",
    "You unlocked the conversation" : "Digoret o peus ar gemenadenn",
    "An administrator unlocked the conversation" : "Ar merour en deus digoret ar gemenadenn",
    "{actor} locked the conversation" : "{actor} en deus seret ar gemenadenn",
    "You locked the conversation" : "Serte ho peus ar gemenadenn",
    "An administrator locked the conversation" : "Ar merour en deus seret ar gemenadenn",
    "The conversation is now open to everyone" : "Digoret eo ar gemenadenn da tout an dud",
    "{actor} opened the conversation to everyone" : "{actor} en deus digoret ar gemenadenn da tout an dud.",
    "You opened the conversation to everyone" : "Digoret ho peus ar gemenadenn da tout an dud.",
    "{actor} restricted the conversation to moderators" : "{actor} en deus bevennet ar gemenadenn d'an habaskaerien",
    "You restricted the conversation to moderators" : "Bevennet ho peus ar gemenadenn d'an habaskaerien",
    "{actor} allowed guests" : "{actor} en deus aotreet kouviidi",
    "You allowed guests" : "Aotreet ho peus kouviidi",
    "An administrator allowed guests" : "Ar merour en deus aotreet kouviidi",
    "{actor} disallowed guests" : "{actor} en deus disaotreet kouviidi",
    "You disallowed guests" : "Disaotreet ho peus kouviidi",
    "An administrator disallowed guests" : "Ar merour en deus disaotreet kouviidi",
    "{actor} set a password" : "{actor} en/he deus termenet ur ger-tremen",
    "You set a password" : "Termenet ho peus ur ger-tremen",
    "An administrator set a password" : "Ur merour en/he deus termenet ur ger-tremen",
    "{actor} removed the password" : "{actor} en/he deus dilamet ar ger-tremen",
    "You removed the password" : "Dilamet ho peus ar ger-tremen",
    "An administrator removed the password" : "Ur merour en/he deus dilamet ar ger-tremen",
    "{actor} added {user}" : "{actor} en deus ouzhpennet {user}",
    "You joined the conversation" : "Deuet oc'h er gemenadenn",
    "{actor} joined the conversation" : "{actor} a zo deuet er gemenadenn",
    "You added {user}" : "Ouzhpennet ho peus {user}",
    "{actor} added you" : "{actor} en deus ouzhpennet ac'hanoc'h",
    "An administrator added you" : "Ur merour en deus ouzhpennet ac'hanoc'h",
    "An administrator added {user}" : "Ur merour en deus uzhpennet {user}",
    "You left the conversation" : "Kuitaet ho peus ar gemenadenn",
    "{actor} left the conversation" : "{actor} en deus kuitaet ar gemenadenn",
    "{actor} removed {user}" : "{actor} en deus lemet {user}",
    "You removed {user}" : "Lamet ho peus {user}",
    "{actor} removed you" : "{actor} en deus lemet ac'hanoc'h",
    "An administrator removed you" : "Ur merour en deus lamet ac'hanoc'h",
    "An administrator removed {user}" : "Ur merour en deus lamet {user}",
    "{actor} promoted {user} to moderator" : "{actor} en deus lakaet {user} da habaskaer",
    "You promoted {user} to moderator" : "Lakaet ho peus {user} da habaskaer",
    "{actor} promoted you to moderator" : "{actor} en deus lakaet ac'hanoc'h da habaskaer",
    "An administrator promoted you to moderator" : "Ur merour en deus lakaet ac'hanoc'h da habaskaer",
    "An administrator promoted {user} to moderator" : "Ur merour en deus lakaet {user} da habaskaer",
    "{actor} demoted {user} from moderator" : "{actor} en deus lamet da {user} e droet habaskaer ",
    "You demoted {user} from moderator" : "Lamet ho peus da {user} e droet habaskaer ",
    "{actor} demoted you from moderator" : "{actor} en deus lamet deioc'h ho droet habaskaer ",
    "An administrator demoted you from moderator" : "Ur merour en deus lamet deoc'h ho droet habaskaer ",
    "An administrator demoted {user} from moderator" : "Ur merour en deus lamet da {user} e droet habaskaer ",
    "{actor} shared a file which is no longer available" : "Restr rannet {actor} n'eo ket posupl kavout kenn",
    "You shared a file which is no longer available" : "Ar restr o peus rannet n'eo ket posupl kavout kenn",
    "%s (guest)" : "%s (kouviat)",
    "You missed a call from {user}" : "C'hwitet o peus ur gemenadenn eus {user}",
    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Kemenadenn gant %n kouviad (Padelez {duration})","Kemenadenn gant %n kouviad (Padelez {duration})","Kemenadenn gant %n kouviad (Padelez {duration})","Kemenadenn gant %n kouviad (Padelez {duration})","Kemenadenn gant %n kouviad (Padelez {duration})"],
    "Call with {user1} and {user2} (Duration {duration})" : "Kemenadenn gant {user1} ha {user2} (Padelez {duration})",
    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Kemenadenn gant {user1}, {user2} ha {user3} (Padelez {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Kemenadenn gant {user1}, {user2}, {user3} ha {user4} (Padelez {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Kemenadenn gant {user1}, {user2}, {user3}, {user4} ha {user5} (Padelez {duration})",
    "Talk to %s" : "Komz da %s",
    "File is not shared, or shared but not with the user" : "N'eo ket rannet ar restr, pe n'eo ket rannet gan an implijour",
    "No account available to delete." : "N'ez eus kont ebet da lemel",
    "File is too big" : "Re vras eo ar restr",
    "Invalid file provided" : "Ar restr roet n'eo ket unan aotreet",
    "Invalid image" : "N'eo ket aotreet ar skeudenn",
    "Unknown filetype" : "N'eo ket anavezet stumm ar restr",
    "Talk mentions" : "Menegoù Talk",
    "Call in progress" : "Kemenadenn en dro",
    "You were mentioned" : "Meneget oc'h bet",
    "Write to conversation" : "Skrivañ d'an diviz",
    "Writes event information into a conversation of your choice" : "Skriva titouroù an darvout en diviz o peus c'hoant",
    "%s invited you to a conversation." : "%s en deus kouviet ac'hanoc'h dan diviz",
    "You were invited to a conversation." : "Kouviet oc'h en un diviz",
    "Conversation invitation" : "Kouviadenn diviz",
    "Click the button below to join." : "Klikit war ar bouton evit mont",
    "Join »%s«" : "Mont da »%s«",
    "Password request: %s" : "Ger-tremen goulennet : %s",
    "Private conversation" : "Diviz prevez",
    "Deleted user (%s)" : "Lemel implijour (%s)",
    "Dismiss notification" : "Arrest ar gemenadennoù",
    "{user} in {call}" : "{user} e {call}",
    "Deleted user in {call}" : "Lemel implijer e {call}",
    "{guest} (guest) in {call}" : "{guest} (kouviad) e {call}",
    "Guest in {call}" : "Kouvidi e {call}",
    "{user} sent you a private message" : "{user} en deus kaser deoc'h ur gemenadenn prevez",
    "{user} sent a message in conversation {call}" : "{user} en deus kaset ur gemenadenn en diviz {call}",
    "A deleted user sent a message in conversation {call}" : "Un implijer lamet en deus kaset ur gemenadenn en diviz {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (kouviat) en deus kaset ur gmenadenn en diviz {call}",
    "A guest sent a message in conversation {call}" : "Ur c'houviat en deus kaset ur gemenaden en diviz {call}",
    "{user} replied to your private message" : "{user} en deus responted d'ho gemenadenn prevez",
    "{user} replied to your message in conversation {call}" : "{user} en deus respontet d'ho gemenadenn en diviz {call}",
    "A deleted user replied to your message in conversation {call}" : "U implijour lamet en deus responted d'o gemenadenn en diviz {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (kouviat) en deus responted d'ho gemenadenn en diviz {call}",
    "A guest replied to your message in conversation {call}" : "Ur c'houviat en deus responted d'ho gemenadenn en diviz {call}",
    "{user} mentioned you in a private conversation" : "{usetr} en deus meneget ac'hanoc'h en un diviz prevez",
    "{user} mentioned you in conversation {call}" : "{user} en deus meneget ac'hanoc'h en diviz {call}",
    "A deleted user mentioned you in conversation {call}" : "Un implijour lamet en deus meneget ac'hanoc'h en diviz {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (kouviat) en deus meneget ac'hanoc'h en diviz {call}",
    "A guest mentioned you in conversation {call}" : "Ur c'houviat en deus meneget ac'hanoc'h en diviz {call}",
    "View chat" : "Gwellet ar chat",
    "{user} invited you to a private conversation" : "{user} en deus kouviet ac'hanoc'h en un diviz prevez",
    "Join call" : "Mont er gemenadenn",
    "{user} invited you to a group conversation: {call}" : "{user} e deus kouviet ac'hnoc'h d'ur strolat diviz : {call}",
    "Answer call" : "Respont d'ar gemenadenn",
    "Call back" : "adober ur gemenadenn",
    "A group call has started in {call}" : "Ur gemenadenn strollat a zo kroget e {call}",
    "You missed a group call in {call}" : "C'hwitet ho peus ur gemenadenn strollat e {call}",
    "{email} is requesting the password to access {file}" : "{email} a goulenn ar ger-tremen evit tizout {restr}",
    "{email} tried to request the password to access {file}" : "{email} en deus goulennet ar ger-tremen evit tizout {restr}",
    "Someone is requesting the password to access {file}" : "Unan bennak a zo o gouelnn ar ger tremen evit tizout {restr}",
    "Someone tried to request the password to access {file}" : "Unan bennak en deus klasket goulenn ar ger-tremen evit tizhout {file}",
    "Open settings" : "Digeri stummoù",
    "The hosted signaling server is now configured and will be used." : "Ar servijour kemenn ostet a zo stummet hag a vo implijet bremañ.",
    "The hosted signaling server was removed and will not be used anymore." : "Lamet eo bet ar servijour kemenn ostet ha ne vo ket implijet kenn.",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "Ar servijour kemenn ostet en deus cheñchet eus \"{oldstatus}\" da \"{newstatus}\".",
    "Conversations" : "Diviz",
    "Messages" : "Kemenadennoù",
    "{user}" : "{user}",
    "Messages in {conversation}" : "Kemenadennoù e {conversation}",
    "{user} in {conversation}" : "{user} e {conversation}",
    "Messages in other conversations" : "Kemenadennoù e divizoù all",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "C'hwitet eo bet goulenn an arnodenn, abalamour ne vez ket tizet ar servijour anodañ. klaskit en dro diwezatoc'h.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "Ur gudenn a zo gant dilesa an azgoulenn. Mateze ne vez get tizet dre ar maez evit gwiriañ e URL.",
    "Something unexpected happened." : "Un dra dic'hortoz a zo degouezet.",
    "The URL is invalid." : "Fall eo an url",
    "An HTTPS URL is required." : "Un URL HTTPS a zo ret kaout.",
    "The email address is invalid." : "N'eo ket mat ar chom-lech postel",
    "The language is invalid." : "N'eo ket mat ar yezh.",
    "The country is invalid." : "N'eo ket mat ar bro.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "Ur guden a zo gant ar goulenn arnodenn. Selit ouh ho kazetenn evit muioc'h a ditouroù.",
    "Too many requests are send from your servers address. Please try again later." : "Re a goulennoù a vez kaset da chom-lec'h ar servijour. Klaskit en dro divesatoc'h.",
    "There is already a trial registered for this Nextcloud instance." : "Un arnodenn a zo bet goulenet d'an azgoulenn Newtcloud dija.",
    "Something unexpected happened. Please try again later." : "Un dra dic'hortozh a zo degouezet. Klaskit en dro diwezatoc'h.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "C'hwitet da goulenn an amprouadenn ablamour ne dro ket mat ar servijour amprouiñ. Klaskit en dro diwezatoc'h.",
    "Trial requested but failed to get account information. Please check back later." : "Amprouadenn  goulennet mes c'hwitet da tapout titouroù ar c'hont. Klaskit en dro diwezatoc'h.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "Ur gudenn a zo gant dilesa ar goulenn. Marteze ne vez ket tizet dre ar maez evit gwiriañ an URL.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "C'hwitet da dapout titouroù ar c'hont peogwir ne dro ket mat ar servijour amprouiñ. Klaskit en dro diwezatoc'h.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "Ur gudenn a zo gant pakañ titouroù ar c'hont. Sellit ho kazetnn evit muioc'h a ditouroù.",
    "There is no such account registered." : "N'ez eus kont evel se ebet enrollet.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "'hwitet da dapout titouroù ar c'hont peogwir ne vez ket tizet ar servijour amprouiñ. Klaskit en dro diwezatoc'h.",
    "Deleting the hosted signaling server account failed. Please check back later." : "C'hwitet da lemel ar servijour gemenn ostet. Klaskit en dro diwezatoc'h",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "C'hwitet da lemel ar c'hont peogwir ne dro ket mat ar serviojour ammprouiñ. Klaskit en dro diwezatoc'h.",
    "There is a problem with deleting the account. Please check your logs for further information." : "Ur gudenn a zo en ur lemel arc'hont. Sellit ouzh ho kaetenn evit muioc'h ha ditouroù.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "C'hwitet da lemel ar c'hont peogwir ne vez ket tizet ar servijour amprouiñ. Klaskit en dro diwezatoc'h.",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Emirelezhioù Arab Unanet",
    "Afghanistan" : "Afghanistan",
    "Antigua and Barbuda" : "Antigua ha Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Antarctica" : "Antarktika",
    "Argentina" : "Arc'hantina",
    "American Samoa" : "Samoa Amerikan",
    "Austria" : "Aostria",
    "Australia" : "Aostralia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Åland",
    "Azerbaijan" : "Azerbaidjan",
    "Bosnia and Herzegovina" : "Bosnia-ha-Herzegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bengladesh",
    "Belgium" : "Belgia",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Bahrain" : "Bahrein",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint-Barthélemy",
    "Bermuda" : "Bermuda",
    "Brunei Darussalam" : "Brunei",
    "Bolivia, Plurinational State of" : "Bolivia",
    "Bonaire, Sint Eustatius and Saba" : "Izelvroioù ar c'haraib",
    "Brazil" : "Brazil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhoutan",
    "Bouvet Island" : "Enez Bouvet",
    "Botswana" : "Botswana",
    "Belarus" : "Belarus",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Inizi Cocos (Keeling)",
    "Congo, the Democratic Republic of the" : "Republik Demokratel Kongo",
    "Central African Republic" : "Republik Kreizafrikan",
    "Congo" : "Kongo",
    "Switzerland" : "Suis",
    "Côte d'Ivoire" : "Aod an Olifant",
    "Cook Islands" : "Inizi Cook",
    "Chile" : "Chile",
    "Cameroon" : "Kameroun",
    "China" : "Sina",
    "Colombia" : "Kolombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Kab Glas",
    "Curaçao" : "Kòrsou",
    "Christmas Island" : "Enez Christmas",
    "Cyprus" : "Republik Kiprenez",
    "Czechia" : "Republik Tchek",
    "Germany" : "Alamagn",
    "Djibouti" : "Djibouti",
    "Denmark" : "Danmark",
    "Dominica" : "Dominika",
    "Dominican Republic" : "Republik Dominikan",
    "Algeria" : "Aljeria",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estonia",
    "Egypt" : "Egipt",
    "Western Sahara" : "Sahara ar C'hornôg",
    "Eritrea" : "Eritrea",
    "Spain" : "Spagn",
    "Ethiopia" : "Etiopia",
    "Finland" : "Finland",
    "Fiji" : "Fidji",
    "Falkland Islands (Malvinas)" : "Inizi Maloù",
    "Micronesia, Federated States of" : "Stadoù Kevreet Mikronezia",
    "Faroe Islands" : "Faero",
    "France" : "Bro-C'hall",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "Rouantelezh-Unanet",
    "Grenada" : "Grenada",
    "Georgia" : "Georgia",
    "French Guiana" : "Ginea c'hall",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Jibraltar",
    "Greenland" : "Greunland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Gwadeloup",
    "Equatorial Guinea" : "Ginea ar C'heheder",
    "Greece" : "Gres",
    "South Georgia and the South Sandwich Islands" : "Georgia ar Su hag Inizi Sandwich ar Su",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Ginea-Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Enez Heard hag Inizi McDonald",
    "Honduras" : "Honduras",
    "Croatia" : "Kroatia",
    "Haiti" : "Republik Haiti",
    "Hungary" : "Hungaria",
    "Indonesia" : "Indonezia",
    "Ireland" : "Iwerzhon",
    "Israel" : "Israel",
    "Isle of Man" : "Manav",
    "India" : "India",
    "British Indian Ocean Territory" : "Tiriad Meurvor Indez Breizh-Veur",
    "Iraq" : "Irak",
    "Iran, Islamic Republic of" : "Iran",
    "Iceland" : "Island",
    "Italy" : "Italia",
    "Jersey" : "Jerzenez",
    "Jamaica" : "Jamaika",
    "Jordan" : "Jordania",
    "Japan" : "Japan",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kirgizstan",
    "Cambodia" : "Kambodja",
    "Kiribati" : "Kiribati",
    "Comoros" : "Komorez",
    "Saint Kitts and Nevis" : "Saint Kitts ha Nevis",
    "Korea, Democratic People's Republic of" : "Republik Poblel ha Demokratel Korea",
    "Korea, Republic of" : "Republik Korea",
    "Kuwait" : "Koweit",
    "Cayman Islands" : "Inizi Cayman",
    "Kazakhstan" : "Kazakstan",
    "Lao People's Democratic Republic" : "Laos",
    "Lebanon" : "Liban",
    "Saint Lucia" : "Santez-Lusia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Lituania",
    "Luxembourg" : "Bro Luksembourg",
    "Latvia" : "Latvia",
    "Libya" : "Libia",
    "Morocco" : "Maroko",
    "Monaco" : "Monako",
    "Moldova, Republic of" : "Moldova",
    "Montenegro" : "Montenegro",
    "Saint Martin (French part)" : "Saint-Martin (Antilhez)",
    "Madagascar" : "Madagaskar",
    "Marshall Islands" : "Inizi Marshall",
    "Macedonia, the former Yugoslav Republic of" : "Makedonia an Norzh",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Mariana an Norzh",
    "Martinique" : "Martinik",
    "Mauritania" : "Maouritania",
    "Montserrat" : "Enez Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Moris",
    "Maldives" : "Maldivez",
    "Malawi" : "Malawi",
    "Mexico" : "Mec'hiko",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Mozambik",
    "Namibia" : "Namibia",
    "New Caledonia" : "Kaledonia-Nevez",
    "Niger" : "Niger",
    "Norfolk Island" : "Enez Norfolk",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Nederland",
    "Norway" : "Norvegia",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Zeland-Nevez",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Polinezia C'hall",
    "Papua New Guinea" : "Papoua Ginea-Nevez",
    "Philippines" : "Filipinez",
    "Pakistan" : "Pakistan",
    "Poland" : "Polonia",
    "Saint Pierre and Miquelon" : "Sant-Pêr-ha-Mikelon",
    "Pitcairn" : "Inizi Pitcairn",
    "Puerto Rico" : "Puerto Rico",
    "Palestine, State of" : "Palestinia, Stad",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Katar",
    "Réunion" : "Enez ar Reünion",
    "Romania" : "Roumania",
    "Serbia" : "Serbia",
    "Russian Federation" : "Rusia",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Arabia Saoudat",
    "Solomon Islands" : "Inizi Salomon",
    "Seychelles" : "Sechelez",
    "Sudan" : "Soudan",
    "Sweden" : "Sveden",
    "Singapore" : "Singapour",
    "Saint Helena, Ascension and Tristan da Cunha" : "Saint Helena, Ascension ha Tristan da Cunha",
    "Slovenia" : "Slovenia",
    "Svalbard and Jan Mayen" : "Svalbard ha Jan Mayen",
    "Slovakia" : "Slovakia",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Surinam",
    "South Sudan" : "Soudan ar Su",
    "Sao Tome and Principe" : "São Tomé ha Príncipe",
    "El Salvador" : "El Salvador",
    "Sint Maarten (Dutch part)" : "Sint Maarten (stad)",
    "Syrian Arab Republic" : "Siria",
    "Eswatini" : "Eswatini",
    "Turks and Caicos Islands" : "Inizi Turks ha Caicos",
    "Chad" : "Tchad",
    "French Southern Territories" : "Douaroù Aostral hag Antarktikel Frañs",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tajikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor ar Reter",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunizia",
    "Tonga" : "Tongaeg",
    "Turkey" : "Turkia",
    "Trinidad and Tobago" : "Trinidad ha Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan, Province of China" : "Rapublik Sina",
    "Tanzania, United Republic of" : "Tanzania",
    "Ukraine" : "Ukraina",
    "Uganda" : "Ouganda",
    "United States Minor Outlying Islands" : "Inizi bihan pell diouzh ar Stadoù Unanet",
    "United States of America" : "Stadoù Unanet Amerika",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Ouzbekistan",
    "Holy See" : "Sez Santel",
    "Saint Vincent and the Grenadines" : "Sant Visant hag an Inizi Granadinas",
    "Venezuela, Bolivarian Republic of" : "Venezuela",
    "Virgin Islands, British" : "Inizi Gwerc'h Breizhveurat",
    "Virgin Islands, U.S." : "Inizi Gwerc'h ar Stadoù-Unanet",
    "Viet Nam" : "Viêt Nam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis ha Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Yemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Suafrika",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Invalid date, date format must be YYYY-MM-DD" : "Deizat fall, stumm an deizat a zo ret bezhañ BBBB-MM-DD",
    "Conversation not found" : "N'eo ket bet kavet an diviz",
    "Path is already shared with this room" : "An hent a zo dihja bet rannet gant ar sal",
    "Chat, video & audio-conferencing using WebRTC" : "Chat, video & audio-prezegenn gant WebRTC",
    "Navigating away from the page will leave the call in {conversation}" : "Kuitat ar bajenn a laosko ar pelgomzadenn e {convzersation}",
    "Leave call" : "Kuitat ar gemenadenn",
    "Stay in call" : "Chom er gemenadenn",
    "Duplicate session" : "Eilan dalc'h",
    "Discuss this file" : "Komz diwar benn ar restr-mañ",
    "Share this file with others to discuss it" : "Rannañ ar restr-mañ da reoù all evit komz diwar e-benn",
    "Share this file" : "Rannañ ar restr",
    "Join conversation" : "Mont n diviz",
    "Request password" : "Goulenn ar -ger-tremen",
    "Error requesting the password." : "Ur fazi a zo bet en ur gouelenn ar ger-tremen",
    "This conversation has ended" : "Echu ei an diviz-mañ",
    "Limit to groups" : "Nemet d'ar strolladoù",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "M'az eo choazet ur strollad d'an neubetañ, ne vo nemet tud ar strollad en diviz.",
    "Guests can still join public conversations." : "Kouviidi a c'hell dont en diviz c'hoaz.",
    "Limit using Talk" : "Bevenn en ur implij Talk",
    "Limit creating a public and group conversation" : "Bevenn krouañ un diviz publik hag a stroll",
    "Limit creating conversations" : "Bevenn krouañ un diviz",
    "Limit starting a call" : "Beven kregiñ ur gemenadenn",
    "Limit starting calls" : "Beven kregiñ kemenadennoù",
    "When a call has started, everyone with access to the conversation can join the call." : "P'en deus kroget ur gemenadenn, tout an dud en diviz a c'hell monet er gemenadenn.",
    "Everyone" : "Toud an dud",
    "Users and moderators" : "Implijourien ha habaskaerienn",
    "Moderators only" : "Habaskerienn nemetken",
    "Save changes" : "Enrollañ ar cheñchamantoù",
    "Saving …" : "Orc'h enrolliñ",
    "Saved!" : "Enrollet !",
    "Commands" : "Urzhioù",
    "Beta" : "Beta",
    "Name" : "Anv",
    "Command" : "Urzh",
    "Script" : "Script",
    "Response to" : "Respont da",
    "Enabled for" : "reañ evit",
    "Commands are a new beta feature in Nextcloud Talk. They allow you to run scripts on your Nextcloud server. You can define them with our command line interface. An example of a calculator script can be found in our {linkstart}documentation{linkend}." : "An urzhioù a zo ur perzh nevez e Nextcloud Talk. Aotreañ a reont da lakaat da dreiñ ur skrip war ho servijour Nextcloud. Galout a rit krouañ anezho en ur implij hon etrafas linenn urzh. Ur skouer skript jederez a zo posupl kaout en hon {linkstart}diellvadur{linkend}.",
    "None" : "Hini ebet",
    "User" : "Implijer",
    "Disabled" : "Disaotreañ",
    "Moderators" : "Habaskaer",
    "Users" : "Implijer",
    "General settings" : "Stummoù hollek",
    "Default notification settings" : "Arventennoù kemenadenn dre ziouer",
    "Default group notification" : "Kemenadenn strollad dre ziouer",
    "Default group notification for new groups" : "Kemenadenn strollad dre ziouer evit ar strolladoù nevez",
    "Integration into other apps" : "Lakaet e-barzh meziantoù all",
    "Allow conversations on files" : "Aotreañ an treiñ restroù",
    "Allow conversations on public shares for files" : "Aotreañ divizoù war ranadennoù publik evit ar restroù",
    "All messages" : "Pep kemenadenn",
    "@-mentions only" : "@-meneg nemetkenn",
    "Off" : "Lac'hañ",
    "Hosted high-performance backend" : "Backend a labour buhan osted",
    "URL of this Nextcloud instance" : "URL an azgoulenn Nextcloud",
    "Full name of the user requesting the trial" : "Tout anv an implijer a goulenn an amprouadenn",
    "Language" : "Yezh",
    "Country" : "Bro",
    "Request signaling server trial" : "Goulenn amproui arhent ar servijour",
    "You can see the current status of your hosted signaling server in the following table." : "Posupl eo deoc'h gwellet stad ho arhent ho servijour ostet e daolenn dindan.",
    "Status" : "Stad",
    "Created at" : "Krouet da",
    "Expires at" : "Termen da",
    "Limits" : "Bevennoù",
    "Delete the signaling server account" : "Lemel ar c'hont arhent servijour",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "En ur klikañ war ar bouton a huz an titouroù ar stumm mañ a vo kaset d'ar servijour Struktur AG. Muioc'h a ditouroù war {linkstart}spreed.eu{linkend}.",
    "Pending" : "O c'hortoz",
    "Error" : "Fazi",
    "Blocked" : "Stanket",
    "Active" : "O labourat",
    "Expired" : "Termenet",
    "The trial could not be requested. Please try again later." : "An amprouadenn na c'hell ket bezhañ goulennet. Klaskit en dro goude.",
    "The account could not be deleted. Please try again later." : "Neo ket posupl lemel ar c'hont. Klaskit en dro goude",
    "_%n user_::_%n users_" : ["%n implijer","%n implijer","%n implijer","%n implijer","%n implijer"],
    "Validate SSL certificate" : "Sertifikad SSL gwiriet",
    "Delete this server" : "Lemel ar servijour",
    "Status: Checking connection" : "Stad : Ho gwiriañ ar genstagadenn",
    "OK: Running version: {version}" : "OK : o lakaat da dreiñ ar stumm : {version}",
    "Error: Server did not respond with proper JSON" : "Fazi : N'eo ket posupl respont gant ur JSON mat",
    "Error: Server responded with: {error}" : "Fazi : Respont a ra ar servijour gant : {error}",
    "Error: Unknown error occurred" : "Fazi : Ur fazi dianv a zo bet",
    "Shared secret" : "Secret rannet",
    "High-performance backend URL" : "URL ar vackend a labour buhan",
    "High-performance backend" : "Backend a labour buhan",
    "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "Ur servijour diavaezh arhentañ a c'hell bezhañ implijet evit staliadurioù brasoc'h. Laoskit implij ar servijour arhentañ diabarzh goulo.",
    "It is highly recommended to set up a distributed cache when using Nextcloud Talk together with a High Performance Back-end." : "Aliet kreñv eo staliañ ur c'hach rannet pa implijer Nextcloud Talk gant ur Vack-End Labour Huel.",
    "Don't warn about connectivity issues in calls with more than 4 participants" : "N'om pas kemenn diwar ben kudennom kenstagadur er gemennadennoù gant muioc'h eget 4 implijer.",
    "STUN server URL" : "URL ar servijour STUNN",
    "STUN servers" : "Servijour STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Ur servijour STUNN a vez implijet evit anavezout chom-lec'h IP publik an implijourienn a drek an henter.",
    "TURN server URL" : "URL ar servijour TURN",
    "TURN server secret" : "Servijour TURN sekret",
    "TURN server protocols" : "Protokoloù servijour TURN",
    "OK: Successful ICE candidates returned by the TURN server" : "OK : ICE emstriver mat edkaset gant ar servijour TURN",
    "Error: No working ICE candidates returned by the TURN server" : "Fazi : Ne labour ket ICE emstriver adkaset gant ar servijour TURN",
    "Testing whether the TURN server returns ICE candidates" : "Amprouiñ adkasadenn emstriver ICE at servijour TURN",
    "Test this server" : "Arnodañ ar servijour-mañ",
    "TURN servers" : "Servijour TURN",
    "OK" : "OK",
    "Back" : "Distro",
    "Confirm" : "Kadarnañ",
    "Cancel" : "Arrest",
    "Copy link" : "Kopiañ al liamm",
    "Waiting for others to join the call …" : "O c'hortoz ma teuio ar re all er gemenadenn ...",
    "You can invite others in the participant tab of the sidebar" : "Galout a rit kouviañ tud gant an daolenn lodek er verenn gostez",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Galout a rit kouviañ tud en dolenn lodek er varenn gostez pe rannañ al liamm-mañ evit kouviañ anezho !",
    "Share this link to invite others!" : "Rannit al liamm-mañ gant ar re all !",
    "Mute audio" : "Lac'hañ a audio",
    "Unmute audio" : "Lakaat an odio en dro",
    "Access to camera was denied" : "Nac'het eo bet tizhañ ar c'hamera",
    "Error while accessing camera" : "Ur fazi a zo bet en ur tizhout ar c'hamera",
    "You have been muted by a moderator" : "Mut oc'h bet lakaet gant ar moderatour",
    "Disable video" : "Lac'han ar video",
    "Enable video" : "Lakaat ar video en dro",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Lakaat ar video en dro. Ho genstagadenn a vo troc'het evit aotreañ ar video evit ar wech kentañ",
    "You" : "C'hwi",
    "Show screen" : "Diskwell ar skramm",
    "Stop following" : "Arrest heuliañ",
    "Mute" : "Mut",
    "You need to be logged in to upload files" : "Ret eo deoc'h bezhañ deuet-tre evit pellkas restroù",
    "Drop your files to upload" : "Laoskit ho restroù evit pellkas",
    "Favorite" : "Pennroll",
    "Description" : "Deskrivadur",
    "Conversation settings" : "Stummoù diviz",
    "Personal" : "Personel",
    "Leave conversation" : "Kuitaat an diviz",
    "Delete conversation" : "Lemel an diviz",
    "Do you really want to delete \"{displayName}\"?" : "Sur oc'h da lemel  \"{displayName}\" ?",
    "Submit" : "Kinnig",
    "Password protection" : "Gwareziñ gant ur ger-tremen",
    "Copy conversation link" : "Eilañ al liamm diviz",
    "Start time (optional)" : "Amzer kregiñ (dibab)",
    "Save" : "Enrollañ",
    "Edit" : "Cheñch",
    "More information" : "Muioc'h a ditouroù",
    "Delete" : "Lemel",
    "Password" : "Ger-tremen",
    "Login" : "Anv arveriad",
    "Client ID" : "ID kliant",
    "Notifications" : "Kemennadennoù",
    "Remove from favorites" : "Diverkañañ eus ar pennrolloù",
    "Add to favorites" : "Ouzhpennañ er pennrolloù",
    "You: {lastMessage}" : "C'hwi : {lastMessage}",
    "{actor}: {lastMessage}" : "{actor} : {lastMessage}",
    "You need to promote a new moderator before you can leave the conversation." : "Ret eo deoc'h lakaat unan bennak da moderatour a-rao kuitaat an diviz.",
    "Loading" : "Kargañ",
    "No search results" : "Disoc'h enklask ebet",
    "Groups" : "Strolladoù",
    "Circles" : "Kelc'hioù",
    "Users, groups and circles" : "Implijouirinn, stroladoù ha kelc'hioù.",
    "Users and groups" : "Implijourienn ha strolladoù",
    "Users and circles" : "Implijourien ha kelc'hioù",
    "Groups and circles" : "Strolladoù ha kelc'hioù",
    "Other sources" : "Orin all",
    "An error occurred while performing the search" : "Ur fazi a zo bet en ur ober an enklask",
    "Create a new group conversation" : "Krouiñ un diviz strollad nevez",
    "Password protect" : "Ger-tremen gwarezet",
    "Creating your conversation" : "Krouiñ ho diviz",
    "All set" : "Staliet pep tra",
    "Error while creating the conversation" : "Ur fazi a zo bet en ur krouiñ an diviz",
    "Create conversation" : "Krouiñ un diviz",
    "Add participants" : "Ouzhpennan tud",
    "Close" : "Serriñ",
    "Search participants" : "Klask implijer",
    "Conversation name" : "Anv diviz",
    "You are currently waiting in the lobby" : "Ho gortoz er sal gortoz emaoc'h",
    "No microphone available" : "Mikro ebet kavet",
    "Select microphone" : "Choaz ur mikro",
    "No camera available" : "Kamera ebet kavet",
    "Select camera" : "Choaz ur c'hamera",
    "Done" : "Graet",
    "No audio" : "Audio ebet",
    "No camera" : "Kamera ebet",
    "Upload" : "Pellkas",
    "Files" : "Restroù",
    "File to share" : "Restr da rannañ",
    "Invalid path selected" : "An hent dibabet n'eus ket anezhañ",
    "Dismiss" : "Arrest",
    "Reply" : "Respont",
    "Go to file" : "Mont d'ar restr",
    "Translate" : "Treiñ",
    "Today" : "Hiziv",
    "Yesterday" : "Dec'h",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Add emoji" : "Ouzhpennañ un emoji",
    "Send message" : "Kas ur gemenadenn",
    "Write message, @ to mention someone …" : "Skrivañ ur gemenadenn, @ evit menegiñ unan bennak ...",
    "Group" : "Stollad",
    "Share files to the conversation" : "Rannañ restroù d'an diviz",
    "New file" : "Restr nevez",
    "Settings" : "Arventennoù",
    "Send" : "Kas",
    "Add more files" : "Ouzhpennañ muioc'h a restroù",
    "Join" : "Kejañ",
    "moderator" : "habaskaer",
    "guest" : "kouviad",
    "Demote from moderator" : "Lemel eus ar moderatourienn",
    "Promote to moderator" : "Lakaat da moderatour",
    "Remove participant" : "Lemel an den",
    "Add users" : "Ouzhpennañ implijer ",
    "Add groups" : "Ouzhoennañ strolladoù",
    "Add emails" : "Ouzhpennañ postelloù",
    "Add circles" : "Ouzhpennañ kelc'hioù",
    "Searching …" : "O klask ...",
    "No results" : "Disoc'h ebet",
    "Search for more users" : "Klask d evit muioc'h a implijourienn.",
    "Add users, groups or circles" : "Ouhzpennañ implijourienn, strolladoù pe kelc'hioù",
    "Add users or groups" : "Ouzhpennañ implijourienn pe strolladoù",
    "Add users or circles" : "Ouhzpennañ implijourienn pe kelc'hioù",
    "Add groups or circles" : "Ouhzpennañ strolladoù pe kelc'hioù",
    "Add other sources" : "Ouzhpennañ dre un orin all",
    "Participants" : "Tud",
    "Chat" : "Chat",
    "Details" : "Munudoù",
    "Projects" : "Raktres",
    "Search conversations or users" : "Klask divizoù ha implijourienn",
    "Select conversation" : "Choaz un diviz",
    "Link to a conversation" : "Liamm d'an diviz",
    "Choose devices" : "Choazit un ardivink",
    "Attachments folder" : "Teuliad stag",
    "Privacy" : "Prevezder",
    "Search" : "Klask",
    "Select location for attachments" : "Choazit ul lec'h evit stagañ",
    "Error while setting attachment folder" : "Ur fazi a zo bet en ur lakaat an teuliad stagañ",
    "Start call" : "Kregiñ ar gemenadenn",
    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Adnevesaet e bet Nextcloud Talk, ret eo deoc'h freskaat ar bajenn a raok kregiñ pe mont en ut gamanadenn.",
    "You will be able to join the call only after a moderator starts it." : "Posupl vo deoc'h mont er gemenadenn goude ma vo bet groget gant ar modertator.",
    "Open sidebar" : "Digori ar varenn gostez",
    "Show your screen" : "Diskouez ar skramm",
    "Stop screensharing" : "Echuañ ar rannadenn skramm",
    "Screensharing options" : "Dibaboù rannañ skramm",
    "Enable screensharing" : "Aotreañ ar rannan skramm",
    "Bad sent video and screen quality." : "Fall eo perzh ar skramm ha kasadenn ar video.",
    "Bad sent screen quality." : "Fall eo perzh ar skramm.",
    "Bad sent video quality." : "Fall eo perzh ar gasadenn ar video.",
    "Bad sent audio, video and screen quality." : "Fall eo perzh ar skramm, kasadenn ar video ha kasadenn an audio.",
    "Bad sent audio and screen quality." : "Fall eo perzh ar skramm ha kasadenn an audio.",
    "Bad sent audio and video quality." : "Fall eo kasadenn ar video ha kasadenn an audio.",
    "Bad sent audio quality." : "Fall eo kasadenn an audio.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Ho kenstagadenn internet pe urzhiataer a labour ha ne c'hell ket ar re all gwellet ho skramm",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "HO labour eo ho kenstagadenn internet pe ho urzhiataer ha ne c'hell ket ar re all gwellet ac'hanaoc'h.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Ho kenstagadur internet pe ho urzhiataer a labour hamarteze ne c'hll ket komprenn ha gwellet ac'hnoc'h. Evit gwelaat ar stad klaskit lac'han ar video pa rannit ho skramm.",
    "Disable screenshare" : "Rannañ skramm disaotreet",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Ho kenstagadenn internet pe ho urzhiataer a labour ha ne c'hll ket marteze ar re all komprenn ac'hanaoc'h. La'hit ar video evit gwelaat an traoù.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Ho kenstagadenn onternet pe ho urzhiataer a labour ha marteze ne c'hell ket ar re all komprenn ac'hanoc'h.",
    "Screen sharing is not supported by your browser." : "N'eo ket douget ar rannañ skramm gant ho furcher.",
    "Screen sharing requires the page to be loaded through HTTPS." : "Ar rannañ skramm en deus ezhomm e vefe ar bajenn karget dre HTTPS",
    "Screensharing requires the page to be loaded through HTTPS." : "Ar rannañ-skramm en deus ezhomm e vefe ar bajenn karget dre HTTPS",
    "Sharing your screen only works with Firefox version 52 or newer." : "Rannañ  ho skramm a dro nmetken gant  Firefox stumm 52 pe nevezoc'h.",
    "Screensharing extension is required to share your screen." : "Un astenn rannañ-skramm ez eus ezhomm evit rannañ ho srkamm.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Implijit furcherienn disheñvel evel firefox pe Chrome evit rannañ ho skramm.",
    "An error occurred while starting screensharing." : "Ur fazi a zo bet e pad ar rannadenn-skramm.",
    "Mute others" : "Lakaat ar re all mut",
    "Grid view" : "Diskwell ar roued",
    "No unread mentions" : "Kemenadenn nan-lennet ebet",
    "Say hi to your friends and colleagues!" : "Lâr koukouk d'ho mignoned ha genseurted",
    "Start a conversation" : "Kregiñ un diviz",
    "Message without mention" : "Kemenn hp meneg",
    "Mention myself" : "Meneg ac'hanon",
    "Mention room" : "Sal meneg",
    "The conversation does not exist" : "N'ez eus ket eus an diviz-mañ",
    "Join a conversation or start a new one!" : "Mont en un diviz pe kregiñ unan nevez !",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Deuet oc'h en diviz dre ur prenestr pe ardivink all. N'eo ket douget evit ar poent gant Nextcloud Talk neuze eo bet sertet an dalc'h.",
    "Join a conversation or start a new one" : "Mont en un diviz pe kregiñ unan nevez ",
    "Calls are not supported in your browser" : "N'eo ket douget ar gemenadennoù gant ho vrowser",
    "Access to microphone is only possible with HTTPS" : "N'eo posupl tizhout ar mikro nemet gant HTTPS",
    "Access to microphone was denied" : "N'eo ket aotreet tizhout ar mikro",
    "Error while accessing microphone" : "Ur fazi a zo bet en ur tizhout ar mikro",
    "Access to camera is only possible with HTTPS" : "Tizhout ar c'hamera n'eo posupl nemet gant HTTPS",
    "An error occurred while fetching the participants" : "Ur fazi a zo bet en ur pakañ an tud",
    "Media" : "Media",
    "Audio" : "Audio",
    "Other" : "All",
    "Nextcloud Talk was updated, please reload the page" : "Adnevesaet eo bet Nextcloud Talk , adkargit ar bajenn",
    "Do not disturb" : "Na rannit ket",
    "Away" : "Pell",
    "Error while sharing file" : "Ur fazi a zo bet en ur rannañ ar restr",
    "Failed to join the conversation. Try to reload the page." : "C'hwitet da mont en diviz. Klaksit adkargañ ar bajenn.",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Ho klask mont en diviz emaoc'h p'ho peus un dalc'h en ur prenestr pe ardivink all. N'eo ket douget c'hoaz gant Nextcloud Talk. Petra o peus c'hoant ober ?",
    "Join here" : "Kejañ amañ",
    "Leave this page" : "Kuitaat ar bajenn",
    "Nextcloud is in maintenance mode, please reload the page" : "E stumm dalc'h eo Nextcloud, adkargit ar bajenn",
    "Lost connection to signaling server. Trying to reconnect." : "Kenstagadenn gant ar servijour arhent kollet. O klask adkemprenn.",
    "Lost connection to signaling server. Try to reload the page manually." : "Kenstagadenn gant ar servijour arhent kollet. Klaskit adkemprenn gant an dorn.",
    "Establishing signaling connection is taking longer than expected …" : "Lakaat an arhent kenstagañ a zo hiroc'h eget gortozet ...",
    "Failed to establish signaling connection. Retrying …" : "C'hwitet da lakaat an arhent kemprenn. O klask en dro ...",
    "Default" : "Dre ziouer",
    "Microphone {number}" : "Mikro {number}",
    "Camera {number}" : "Kamera {number}",
    "Speaker {number}" : "Huel-gomzerioù {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Seblant a rit bezhaén ho komz p'emaoc'h bet lakaet da mut, dimutit ac'hanoc'h evit bezhañ klevet gant ar re all",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Ne oa ket posupl en em genstagañ gant un implijer d'an neubetañ. Ur servijour TURN a zo marteze ezhomm evit diskoulmañ ze. Goulennit d'ho merour da lakat unan en ur heuliañ  {linkstart}an dielvadur-mañ{linkend}.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Kemer a ra muioc'h a amzer eget ragjedet. Hag aotreoù ar media a zo bet lakaet mat (pe difennet) ? M'eo mat adlakit da vont en dro ho furcher, evel ne labour ket an audio hag ar video",
    "Access to microphone & camera is only possible with HTTPS" : "Tizhout ar mikro hag ar c'hamero a zo posupl nemet gant HTTPS",
    "Please move your setup to HTTPS" : "Lakait ho staliadur da HTTPS mar-plij",
    "Access to microphone & camera was denied" : "Tizhañ ar mikro hag ar c'hmera a zo bet difennet",
    "WebRTC is not supported in your browser" : "N'eo ket douget WebRTC gant ho furcher",
    "Please use a different browser like Firefox or Chrome" : "Implijit furcherienn disheñvel evel Firefox pe Chrome",
    "Error while accessing microphone & camera" : "Ur fazi a zo bet en ur klask tizout ar mikro hag ar c'hamera",
    "The password is wrong. Try again." : "Direizh eo ar ger-tremen. Klaskit en-dro.",
    "Specify commands the users can use in chats" : "Lakait peseurt urzhioù eo posupl d'an implijer implij er chat",
    "TURN server" : "Servijour TRUN",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "Ar servijour TURN a zo implijet evit proksiañ froud an implijaderien a-drek ur voger-dan.",
    "Signaling servers" : "Arhent Servijour",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Ur servijour arhent diavaez a c'hell bezhañ implijet evit staliadurioù brasoc'h. Laoskit implij ar servijour arhent diabarzh goullo.",
    "%s Talk on your mobile devices" : "%s Talk war ho ardivinkoù hezoug",
    "Join conversations at any time, anywhere, on any device." : "Kit en diviz n'eus forzh peseurt amzer, lec'h pe ardivink.",
    "Android app" : "Meziant Android",
    "iOS app" : "Meziant iOS",
    "Name of the user requesting the trial" : "Anv an implijet a goulenn an amprouadenn",
    "Please note that calls with more than 4 participants without external signaling server, participants can experience connectivity issues and cause high load on participating devices." : "Notennit c''hell an implijourien, evit kemenadennoù gant muioc'h eget 4 implijer gant ur servijour arhent diavaez, kaout kudennoù kenstagadeur ha lakaat kargoù bras var ardivinkoù an impklijour.",
    "Conversation link copied to clipboard." : "Liamm diviz eilet er golver",
    "The link could not be copied." : "Ne oa ket posupl eilañ al liamm.",
    "No matches" : "Kejadenn ebet",
    "Link copied to the clipboard!" : "Liamm eilet d'ar golver",
    "Toggle fullscreen" : "Lakat/Kuitaat ar skramm a bezh",
    "Rename conversation" : "Adenvel an diviz",
    "Sending signaling message has failed." : "Kasadenn ar gemenadenn arhentañ a zo c'hwitet."
},
"nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
